@@ -250,6 +250,14 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#cancel_service_pipeline_deployment)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#close)
+        """
+
     def create_component(
         self,
         *,
@@ -355,8 +363,7 @@ class ProtonClient(BaseClient):
         tags: Sequence[TagTypeDef] = ...
     ) -> CreateRepositoryOutputTypeDef:
         """
-        Create and register a link to a repository that can be used with self-managed
-        provisioning (infrastructure or pipelines) or for template sync configurations.
+        Create and register a link to a repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.create_repository)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_repository)
@@ -430,7 +437,8 @@ class ProtonClient(BaseClient):
         subdirectory: str = ...
     ) -> CreateTemplateSyncConfigOutputTypeDef:
         """
-        Set up a template to create new template versions automatically.
+        Set up a template to create new template versions automatically by tracking a
+        linked repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.create_template_sync_config)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_template_sync_config)
@@ -546,7 +554,7 @@ class ProtonClient(BaseClient):
 
     def get_account_settings(self) -> GetAccountSettingsOutputTypeDef:
         """
-        Get detail data for the Proton pipeline service role.
+        Get detail data for Proton account-wide settings.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_account_settings)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_account_settings)
@@ -601,7 +609,7 @@ class ProtonClient(BaseClient):
         self, *, name: str, provider: RepositoryProviderType
     ) -> GetRepositoryOutputTypeDef:
         """
-        Get detail data for a repository.
+        Get detail data for a linked repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_repository)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_repository)
@@ -793,7 +801,7 @@ class ProtonClient(BaseClient):
         self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListRepositoriesOutputTypeDef:
         """
-        List repositories with detail data.
+        List linked repositories with detail data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_repositories)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_repositories)
@@ -956,11 +964,13 @@ class ProtonClient(BaseClient):
     def update_account_settings(
         self,
         *,
+        deletePipelineProvisioningRepository: bool = ...,
         pipelineProvisioningRepository: RepositoryBranchInputTypeDef = ...,
         pipelineServiceRoleArn: str = ...
     ) -> UpdateAccountSettingsOutputTypeDef:
         """
-        Update the Proton service pipeline role or repository settings.
+        Update Proton settings that are used for multiple services in the Amazon Web
+        Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.update_account_settings)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_account_settings)
@@ -1125,7 +1135,7 @@ class ProtonClient(BaseClient):
     ) -> UpdateTemplateSyncConfigOutputTypeDef:
         """
         Update template sync configuration parameters, except for the `templateName` and
-        `templateType` .
+        `templateType`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.update_template_sync_config)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_template_sync_config)
