@@ -60,8 +60,7 @@ Usage::
 import sys
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import (
     EnvironmentAccountConnectionRequesterAccountTypeType,
@@ -133,7 +132,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListComponentOutputsPaginator(Boto3Paginator):
+class ListComponentOutputsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponentOutputs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentoutputspaginator)
@@ -148,7 +147,7 @@ class ListComponentOutputsPaginator(Boto3Paginator):
         """
 
 
-class ListComponentProvisionedResourcesPaginator(Boto3Paginator):
+class ListComponentProvisionedResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponentProvisionedResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentprovisionedresourcespaginator)
@@ -163,7 +162,7 @@ class ListComponentProvisionedResourcesPaginator(Boto3Paginator):
         """
 
 
-class ListComponentsPaginator(Boto3Paginator):
+class ListComponentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentspaginator)
@@ -183,7 +182,7 @@ class ListComponentsPaginator(Boto3Paginator):
         """
 
 
-class ListEnvironmentAccountConnectionsPaginator(Boto3Paginator):
+class ListEnvironmentAccountConnectionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentAccountConnections)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listenvironmentaccountconnectionspaginator)
@@ -203,7 +202,7 @@ class ListEnvironmentAccountConnectionsPaginator(Boto3Paginator):
         """
 
 
-class ListEnvironmentOutputsPaginator(Boto3Paginator):
+class ListEnvironmentOutputsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentOutputs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listenvironmentoutputspaginator)
@@ -218,7 +217,7 @@ class ListEnvironmentOutputsPaginator(Boto3Paginator):
         """
 
 
-class ListEnvironmentProvisionedResourcesPaginator(Boto3Paginator):
+class ListEnvironmentProvisionedResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentProvisionedResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listenvironmentprovisionedresourcespaginator)
@@ -233,7 +232,7 @@ class ListEnvironmentProvisionedResourcesPaginator(Boto3Paginator):
         """
 
 
-class ListEnvironmentTemplateVersionsPaginator(Boto3Paginator):
+class ListEnvironmentTemplateVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentTemplateVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listenvironmenttemplateversionspaginator)
@@ -252,7 +251,7 @@ class ListEnvironmentTemplateVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListEnvironmentTemplatesPaginator(Boto3Paginator):
+class ListEnvironmentTemplatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentTemplates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listenvironmenttemplatespaginator)
@@ -267,7 +266,7 @@ class ListEnvironmentTemplatesPaginator(Boto3Paginator):
         """
 
 
-class ListEnvironmentsPaginator(Boto3Paginator):
+class ListEnvironmentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listenvironmentspaginator)
@@ -285,7 +284,7 @@ class ListEnvironmentsPaginator(Boto3Paginator):
         """
 
 
-class ListRepositoriesPaginator(Boto3Paginator):
+class ListRepositoriesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListRepositories)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listrepositoriespaginator)
@@ -300,7 +299,7 @@ class ListRepositoriesPaginator(Boto3Paginator):
         """
 
 
-class ListRepositorySyncDefinitionsPaginator(Boto3Paginator):
+class ListRepositorySyncDefinitionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListRepositorySyncDefinitions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listrepositorysyncdefinitionspaginator)
@@ -320,7 +319,7 @@ class ListRepositorySyncDefinitionsPaginator(Boto3Paginator):
         """
 
 
-class ListServiceInstanceOutputsPaginator(Boto3Paginator):
+class ListServiceInstanceOutputsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstanceOutputs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listserviceinstanceoutputspaginator)
@@ -339,7 +338,7 @@ class ListServiceInstanceOutputsPaginator(Boto3Paginator):
         """
 
 
-class ListServiceInstanceProvisionedResourcesPaginator(Boto3Paginator):
+class ListServiceInstanceProvisionedResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstanceProvisionedResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listserviceinstanceprovisionedresourcespaginator)
@@ -358,7 +357,7 @@ class ListServiceInstanceProvisionedResourcesPaginator(Boto3Paginator):
         """
 
 
-class ListServiceInstancesPaginator(Boto3Paginator):
+class ListServiceInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listserviceinstancespaginator)
@@ -373,7 +372,7 @@ class ListServiceInstancesPaginator(Boto3Paginator):
         """
 
 
-class ListServicePipelineOutputsPaginator(Boto3Paginator):
+class ListServicePipelineOutputsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServicePipelineOutputs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listservicepipelineoutputspaginator)
@@ -388,7 +387,7 @@ class ListServicePipelineOutputsPaginator(Boto3Paginator):
         """
 
 
-class ListServicePipelineProvisionedResourcesPaginator(Boto3Paginator):
+class ListServicePipelineProvisionedResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServicePipelineProvisionedResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listservicepipelineprovisionedresourcespaginator)
@@ -403,7 +402,7 @@ class ListServicePipelineProvisionedResourcesPaginator(Boto3Paginator):
         """
 
 
-class ListServiceTemplateVersionsPaginator(Boto3Paginator):
+class ListServiceTemplateVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceTemplateVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listservicetemplateversionspaginator)
@@ -422,7 +421,7 @@ class ListServiceTemplateVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListServiceTemplatesPaginator(Boto3Paginator):
+class ListServiceTemplatesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceTemplates)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listservicetemplatespaginator)
@@ -437,7 +436,7 @@ class ListServiceTemplatesPaginator(Boto3Paginator):
         """
 
 
-class ListServicesPaginator(Boto3Paginator):
+class ListServicesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServices)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listservicespaginator)
@@ -452,7 +451,7 @@ class ListServicesPaginator(Boto3Paginator):
         """
 
 
-class ListTagsForResourcePaginator(Boto3Paginator):
+class ListTagsForResourcePaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listtagsforresourcepaginator)
